function [tpp,tps] = fluid_solid(iangd, d1, d2, cp1, cp2, cs2)
% [tpp, tps] = fluid_solid(iangd, d1 , d2, cp1, cp2, cs2) returns ( tpp,
% tps) the plane wave transmission coefficients for a P-wave and S-wave,
% respectively, produced in a solid at a fluid-solid interface due to 
% a P-wave incident at an angle iangd (in degrees). The coefficients are 
% both based on velocity ratios. (d1, cp1) are the density and wave speed
% of the fluid and (d2, cp2, cs2) are the density, P-wave speed, and S-wave
% speed, respectively. The units of these quantities are arbitrary but 
% must be consistent.

% incident angle in radians
iang = (iangd.*pi)./180;

% sines and cosines of the transmitted P- and S-wave angles
sinp = (cp2/cp1)*sin(iang);
sins =(cs2/cp1)*sin(iang);
cosp= (1i*sqrt(sinp.^2 - 1)).*(sinp >= 1) + (sqrt(1 - sinp.^2)).*(sinp < 1);
coss =(1i*sqrt(sins.^2 - 1)).*(sins >= 1) + (sqrt(1 - sins.^2)).*(sins < 1);

% transmission coefficients
denom = cosp + (d2/d1)*(cp2/cp1)*sqrt(1-sin(iang).^2).* ...
    (4.*((cs2/cp2)^2).*(sins.*coss.*sinp.*cosp) + 1 - 4.*(sins.^2).*(coss.^2));
tpp = (2*sqrt(1 - sin(iang).^2).*(1 - 2*(sins.^2)))./denom;
tps = -(4*cosp.*sins.*sqrt(1 - sin(iang).^2))./denom;
